<?php

class MessagesController extends Zend_Controller_Action
{
	
    
	/**
	 * Initialize action controller here.
	 */
    public function init()
    {
        // Set the flash messenger
		$this->view->flashMessenger = $this->_helper->flashMessenger->getMessages();

        $this->sessionMessage = new Zend_Session_Namespace('sessionMessage');
        $this->sessionUser = new Zend_Session_Namespace('sessionUser');
        
    }


    public function sendMessageAction()
    {
    	$this->view->headTitle('Send Message');
    	$this->view->bodyId = 'send-message-page';

        $this->request = $this->getRequest();

        //user id of receiver
        $id = $this->request->getParam('id');
        if(!empty($id))
        {
            $company = new Application_Model_Tables_Companies();
            $this->view->receiver = $company->fetchRow($company->select()->where('user_id = ?', $id));
            $this->view->receiverId= $id;
        }

        if($this->getRequest()->isXmlHttpRequest())
        {    
            $subject = $this->getRequest()->getPost('subject');
            $message = $this->getRequest()->getPost('message');

            if(!empty($subject) && !empty($message))
            {
                $this->formDatas = $this->getRequest()->getPost();
                $message = new Application_Model_Tables_Messages();
                $message->sendMessage($this->formDatas);
                $this->_helper->json(array('message' => 'Message Succesfully Sent!'));
            }
    	}
    }


    public function mailAction()
    {
        $this->view->headTitle('Mail');
        $this->view->bodyId = 'mail-page';

        $userId = Zend_Auth::getInstance()->getIdentity()->user_id;
        $this->view->userId = $userId;

        $this->view->status = $this->sessionUser->status;

        $adapter = Zend_Db_Table_Abstract::getDefaultAdapter();
        $select = new Zend_Db_Select($adapter);
        $select->from('staff_messages')
               ->joinInner('staff_companies', 'staff_messages.sender_id = staff_companies.user_id', array('company_name'))
               ->where("staff_messages.receiver_id = $userId")
               ->where("staff_messages.status = 'inbox' ")
               ->order(array('staff_messages.date_created DESC', 'staff_messages.read'));
        $results = $adapter->fetchAll($select);
        $this->view->row = $results;
        $this->view->count = count($results);
        //session for last action page
        $this->sessionMessage->location = 'mail';
    }


    public function readAction()
    {
        $this->view->headTitle('Read Message');
        $this->view->bodyId = 'read-message-page';

        $this->request = $this->getRequest();
        $messageId = $this->request->getParam('id');

        //get user id
        $userId = Zend_Auth::getInstance()->getIdentity()->user_id;
        $this->view->userId = $userId;
        $this->view->status = $this->sessionUser->status;

        //location
        $location = $this->sessionMessage->location;

        //adapter for query
        $adapter = Zend_Db_Table_Abstract::getDefaultAdapter();
        $select = new Zend_Db_Select($adapter);

        if($location == 'mail')
        {
            $select->from(array('m' => 'staff_messages'))
                   ->joinInner(array('s' => 'staff_companies'), 'm.sender_id = s.user_id', array('sender_company' => 'company_name'))
                   ->joinInner(array('r' => 'staff_companies'), 'm.receiver_id = r.user_id', array('receiver_company' => 'company_name'))
                   ->where("m.message_id = $messageId");
            $mail = $adapter->fetchRow($select);

            if($userId == $mail['receiver_id'])
            {
                $this->view->row = $mail;
                $this->view->location = $location;

                $read = new Application_Model_Tables_Messages();
                $read->readMessage($messageId);                
            }
            else
            {
                $this->_redirect("messages/$location");
            }
        }

        if($location == 'sent')
        {
            $select->from(array('m' => 'staff_messages'))
                   ->joinInner(array('s' => 'staff_companies'), 'm.sender_id = s.user_id', array('sender_company' => 'company_name'))
                   ->joinInner(array('r' => 'staff_companies'), 'm.receiver_id = r.user_id', array('receiver_company' => 'company_name'))
                   ->where("m.message_id = $messageId");
            $sent = $adapter->fetchRow($select);
            
            if($userId == $sent['sender_id'])
            {
                $this->view->row = $sent;
                $this->view->location ='sent';
            }
            else
            {
                $this->_redirect("messages/$location");
            }
        }

        if($location == 'trash')
        {
            $select->from(array('m' => 'staff_messages'))
                   ->joinInner(array('s' => 'staff_companies'), 'm.sender_id = s.user_id', array('sender_company' => 'company_name'))
                   ->joinInner(array('r' => 'staff_companies'), 'm.receiver_id = r.user_id', array('receiver_company' => 'company_name'))
                   ->where("m.message_id = $messageId");
            $trash = $adapter->fetchRow($select); 

            if($userId == $trash['receiver_id'] || $userId == $trash['sender_id'])           
            {
                $this->view->row = $trash;
                $this->view->location = 'trash';
            }
            else
            {
                $this->_redirect("messages/$location");
            }
        }

        //Setting location session
        $this->sessionMessage->location = $location;

    }

    
    public function sentAction()
    {
        $this->view->headTitle('Sent Items');
        $this->view->bodyId = 'sent-items-page';

        $this->view->status = $this->sessionUser->status;

        $userId = Zend_Auth::getInstance()->getIdentity()->user_id;
        $this->view->userId = $userId;

        $adapter = Zend_Db_Table_Abstract::getDefaultAdapter();
        $select = new Zend_Db_Select($adapter);
        $select->from('staff_messages')
               ->joinInner('staff_companies', 'staff_messages.receiver_id = staff_companies.user_id', array('company_name'))
               ->where("staff_messages.status = 'sent' ")
               ->where("staff_messages.sender_id = $userId")
               ->order("staff_messages.date_created DESC");
        $result = $adapter->fetchAll($select);
        $this->view->row = $result;
        $this->view->count = count($result);

        //session for last action page
        $this->sessionMessage->location = 'sent';
    }


    public function deleteMessageAction()
    {
        $this->request = $this->getRequest();
        $messageId = $this->request->getParam('id');

        $userId = Zend_Auth::getInstance()->getIdentity()->user_id;
        $location = $this->sessionMessage->location;

        if($location == 'mail')
        {
            $inbox = new Application_Model_Tables_Messages();
            $row = $inbox->fetchRow($inbox->select()->where('message_id = ?', $messageId));

            if($userId == $row['receiver_id'])
            {
                $inbox->deleteMessage($messageId);
                $this->_redirect("messages/$location");
            }
        }

        if($location == 'sent')
        {
            $sent = new Application_Model_Tables_Messages();
            $row = $sent->fetchRow($sent->select()->where('message_id = ?', $messageId));

            if($userId == $row['sender_id'])
            {
                $sent->deleteMessage($messageId);
                $this->_redirect("messages/$location");
            }
        }

        if($location == 'trash')
        {

        }
    }


    public function trashAction()
    {
        $userId = Zend_Auth::getInstance()->getIdentity()->user_id;
        $this->view->userId = $userId;

        $this->view->status = $this->sessionUser->status;

        $adapter = Zend_Db_Table_Abstract::getDefaultAdapter();     
        $select = new Zend_Db_Select($adapter);
        $select->from(array('m' => 'staff_messages'))
               ->joinInner(array('s' => 'staff_companies'), 'm.sender_id = s.user_id', 'company_name')
               //->joinInner(array('r' => 'staff_companies'), 'm.receiver_id = r.user_id', array('receiver_company' => 'company_name'))
               ->where("m.status = 'trash'")
               ->where("m.sender_id = $userId")
               ->where("m.location = 'sent'")
               ->orWhere("m.receiver_id = $userId")
               ->where("m.location = 'inbox'")
               ->where("m.status = 'trash'");
               
        $results = $adapter->fetchAll($select);
        $this->view->rows = $results;    
        $this->view->count = count($results);

        $this->sessionMessage->location = 'trash';        
    }


    public function replyAction()
    {
        $this->request = $this->getRequest();
        $messageId = $this->request->getParam('id');
        $location = $this->sessionMessage->location;

        $userId = Zend_Auth::getInstance()->getIdentity()->user_id;
        $this->view->status = $this->sessionUser->status;

        $adapter = Zend_Db_Table_Abstract::getDefaultAdapter();     
        $select = new Zend_Db_Select($adapter);

        $select->from(array('m' => 'staff_messages'))
               ->joinInner(array('s' => 'staff_companies'), 'm.sender_id = s.user_id', array('sender_info' => 'company_name'))
               ->joinInner(array('r' => 'staff_companies'), 'm.receiver_id = r.user_id', array('receiver_info' => 'company_name'))
               ->where("m.message_id = $messageId");
        $message = $adapter->fetchRow($select);
        
        if($userId == $message['receiver_id'] || $userId == $message['sender_id'] )
        {
            $this->view->row = $message;
        }
        else
        {
            $this->_redirect("messages/$location/id/$userId");
        }        

        //if submit is clicked
        if($this->getRequest()->isPost())
        {
            $userId = Zend_Auth::getInstance()->getIdentity()->user_id;

            $message_id = $this->_request->getPost('message_id');
            $receiver_id = $this->_request->getPost('receiver_id');
            $subject = $this->_request->getPost('subject');
            $message = $this->_request->getPost('message');

            $formDatas = $this->getRequest()->getPost();

            if(empty($message_id)  || empty($receiver_id) || empty($subject) || empty($subject) || empty($message) || empty($location))
            {

                $this->view->formDatas = $formDatas;
                $this->view->flashMessenger[] = "<div class = 'msg error'/>One of the fields are empty!</div>";
            }
            else
            {       

                $message = new Application_Model_Tables_Messages();
                $message->sendMessage($formDatas);
                $reply = new Application_Model_Tables_Reply();
                $reply->addReply($formDatas);

                $this->_helper->flashMessenger->addMessage('<p class="msg done">Message Succesfully Sent.</p>');
                $this->_redirect("messages/$location/id/$userId");
            }
            
        }
    }


    public function composeMessageAction()
    {
        //user id of user
        $userId = Zend_Auth::getInstance()->getIdentity()->user_id;
        $this->view->userId = $userId;

        //fetch status of the user and put it on a session
        $users = new Application_Model_Tables_Users();
        $status = $users->fetchRow($users->select()->where('user_id = ' . $userId, 1));
        if($status->status != 'active')
        {
            //$this->sessionUser->status = 'inactive';
            $this->view->status = 'inactive';
        }
        else
        {
            //$this->sessionUser->status = 'active';
            $this->view->status = 'active';
        }

        //query for population recipient
        $adapter = Zend_Db_Table_Abstract::getDefaultAdapter();
        $select = new Zend_Db_Select($adapter);
        $select->from('staff_connection')
               ->joinInner('staff_companies', 'staff_connection.connected_id = staff_companies.user_id', array('company_name'))
               ->where("staff_connection.account_id = $userId")
               ->where("staff_connection.status = 'not-deleted'")
               ->order('staff_companies.company_name');
        $rows = $adapter->fetchAll($select);
        $this->view->count = count($rows);
        $this->view->rows = $rows;

        //if click send message
        if($this->getRequest()->getPost())
        {
            $connectionId = $this->_request->getPost('receiver_id');
            $subject = $this->_request->getPost('subject');
            $message = $this->_request->getPost('message');

            $formDatas = $this->getRequest()->getPost();
            if(empty($connectionId) || empty($subject) || empty($message))
            {
                $this->view->flashMessenger[] = "<div class = 'msg error'/>One of the fields are empty!</div>";
                $this->view->formDatas = $formDatas;
            }
            else
            {
                $connection = new Application_Model_Tables_Connection();
                $result = $connection->fetchRow($connection->select()->where("account_id = $userId && connected_id = $connectionId"));
                if(count($result) > 0)
                {
                    $inbox = new Application_Model_Tables_Messages();
                    $inbox->sendMessage($formDatas);
                    $this->_helper->flashMessenger->addMessage('<p class="msg done">Message Succesfully Sent.</p>');
                    $this->_redirect('messages/compose-message');
                }
                else
                {
                    $this->view->flashMessenger[] = "<div class = 'msg error'>You are not connected with this Company.</div>";
                    $this->view->formDatas = $formDatas;
                }
            }
        }

    }


    public function restoreMessageAction()
    {
        $this->request = $this->getRequest();
        $messageId = $this->request->getParam('id');

        if(empty($messageId) || !isset($messageId))
        {
            $this->_redirect('messages/trash');
        }
        else

        $userId = Zend_Auth::getInstance()->getIdentity()->user_id;
    
        $message = new Application_Model_Tables_Messages();
        $result = $message->fetchRow($message->select()->where('message_id = ?', $messageId));
        $location = $result['location'];

        if($result['status'] == 'trash')
        {
            if($result['sender_id'] == $userId && $location == 'sent')
            {
                $this->_helper->flashMessenger->addMessage('<div class="msg done">Message Succesfully Restored.</div>');
                $message->restoreMessage($messageId, $location);
                $this->_redirect('messages/trash');
            }
            elseif($result['receiver_id'] == $userId && $location == 'inbox')
            {
                $this->_helper->flashMessenger->addMessage('<div class="msg done">Message Succesfully Restored.</div>');
                $message->restoreMessage($messageId, $location);
                $this->_redirect('messages/trash');                
            }
            else
            {
                $this->_helper->flashMessenger->addMessage('<div class="msg error">Please Try Again.</div>');
                //if the id manually enter is not the user message
                $this->_redirect('messages/trash');
            }
        }
        else
        {
            //if the id manually enter is not in trash
            $this->_redirect('messages/trash');
        }
    }


    public function removeMessageAction()
    {
        $userId = Zend_Auth::getInstance()->getIdentity()->user_id;
        $messageId = $this->_request->getParam('id');

        $message = new Application_Model_Tables_Messages();
        $result = $message->fetchRow($message->select()->where("message_id = ?", $messageId)->where("status = ?", 'trash'));
        $location = $result['location'];

        if($result['sender_id'] == $userId && $location == 'sent')
        {
            $this->_helper->flashMessenger->addMessage('<div class="msg done">Message Permanently Deleted.</div>');
            $message->removeMessage($messageId);
            $this->_redirect('messages/trash');
        }
        elseif($result['receiver_id'] == $userId && $location == 'inbox')
        {
            $this->_helper->flashMessenger->addMessage('<div class="msg done">Message Permanently Deleted.</div>');
            $message->removeMessage($messageId);
            $this->_redirect('messages/trash');
        }
        else
        {
            $this->_helper->flashMessenger->addMessage('<div class="msg done">Message Permanently Deleted.</div>');
            $this->_redirect('messages/trash');
        }
    }


}
?>