<?php

class UsersController extends Zend_Controller_Action
{
	
	/**
	 * Before dispatching, check the security in general
 	 */
	public function preDispatch() 
	{
		$this->view->auth = Zend_Auth::getInstance();
		if (!$this->view->auth->hasIdentity()) { 
			$this->_helper->flashMessenger->addMessage('<p class="msg error">Error accessing the resquested page.</p>');
			$this->_redirect('/');
		}
        
        // Check Privilege
        // Controllers and views are accessibleonly by admin
        if (Zend_Auth::getInstance()->getStorage()->read()->privilege != 'admin') {
            $this->_helper->flashMessenger->addMessage('<p class="msg error">Error accessing the resquested page.</p>');
            $this->_redirect('/');
        }
	}
	
    
	/**
	 * Initialize action controller here
	 */
    public function init()
    {
    	// Set the flash messenger	
		$this->view->flashMessenger = $this->_helper->flashMessenger->getMessages();
	}


	/**
	 * Show the member's info
	 */
	public function viewUserAction()
    {
    	$this->view->headTitle('List of all users');
        
        $users = new Application_Model_Tables_Userinfos();
        
        // Fetch users
        $results = $users->fetchAll(null, 'date_added');
                        
		// Zend paginator processs
		$page 		= $this->_getParam('p', 1);
    	$paginator 	= Zend_Paginator::factory($results);
    	$paginator->setItemCountPerPage(30);
    	$paginator->setCurrentPageNumber($page);
        $this->view->users = $paginator;
	}
    
    
    /**
     * Add member account
     */
    public function addUserAction()
    {
        $this->view->headTitle('Create New User Account');
                
        if ($this->getRequest()->isPost()) {
            
       	    $formDatas = $this->getRequest()->getPost();      
            
            // Set the type
            $formDatas['type'] = 'member';
            
            // Validate the form
            $errors = array_merge($this->_helper->validates->credentials($formDatas), $this->_helper->validates->userInfoFields($formDatas));      
            
			// If no errors found, it's now ready to insert to database
			if ($errors == null) {
				$formDatas['privilege'] = 'member';
			   
                // Call the model
				$users = new Application_Model_Tables_Users();
                
				// Get the primary key of users
				$userId = $users->insertUsers($formDatas);
				
                if ($userId != 0) {
					
                    $userInfos = new Application_Model_Tables_Userinfos();
                    
                    // Store primary key at $formDatas array
					$formDatas['user_id'] = $userId;
                    
					if ($userInfos->insertUserinfos($formDatas)) {
						$this->_helper->flashMessenger->addMessage('<p class="msg done">User successfully added.</p>');
						$this->_redirect('users/view-user');
					}
				}
                
			} else {
				$message = '<ul>';
				foreach($errors as $error) {
					$message.= '<li>' . $error . '</li>';
				}
				$message.= '</ul>';
				// $this->_helper->flashMessenger->addMessage('<div class="msg error">' . $message . '</div>');
				$this->view->flashMessenger[] = '<div class="msg error">' . $message . '</div>';  
				$this->view->formDatas = $formDatas;
			}
        }
    }
    
    
    /**
     * Edit member account
     */
     public function editUserAction()
     {
        $this->view->headTitle('Edit User');
        
        // Get the id
        $userId = $this->_getParam('id');
        
   	    $users = new Application_Model_Tables_Users();
        $this->view->formDatas = $users->selectUserWithUserinfo($userId);
                
        if ($this->getRequest()->isPost()) {
            
            $formDatas = $this->getRequest()->getPost();
            
            // Validate the form
            $errors = $this->_helper->validates->memberFields($formDatas); 
            
			// If no errors found, it's now ready to insert to database
			if ($errors == null) {
                if ($memberId != 0) {
                    
                    // Store primary key at $formDatas array
                    $formDatas['member_id'] = $memberId;
                    if ($members->updateMember($formDatas)) {
    					$this->_helper->flashMessenger->addMessage('<p class="msg done">User successfully updated.</p>');
    					$this->_redirect('users/edit-member/id/' . $memberId);
				    }
                }
                
            } else {
				$message = '<ul>';
				foreach($errors as $error) {
					$message.= '<li>' . $error . '</li>';
				}
				$message.= '</ul>';
				// $this->_helper->flashMessenger->addMessage('<div class="msg error">' . $message . '</div>');
				$this->view->flashMessenger[] = '<div class="msg error">' . $message . '</div>';  
				$this->view->formDatas = $formDatas;
            }
        }   
    }
}