<?php
class Application_Model_Tables_Announcements extends Zend_Db_Table_Abstract
{
	/**
	 * Set database table name 
	 */
	protected $_name = 'announcement';
	
	
	/**
	 * Set table prefix 
	 */ 
	public function __construct() 
	{
		// Construct the table prefix	
		$this->_name = Zend_Registry::get('tablePrefix') . $this->_name;
		parent::__construct();
	}


	/**
	 * Return Current Date
	 */
	protected function _dateNow()
	{
		$date = date("Y-m-d H:i:s");
		return $date;
	}

	
	/**
	 * Return Full list of Announcement
	 */	
	public function listAnnouncement()
	{
		$results = $this->fetchAll($this->select()->order('created DESC'));
		return $results;
	}


	/**
	 * Insert/Add Announcement
	 * @param array formDatas
	 */
	public function insertAnnouncement($formDatas = array())
	{
		$userId = Zend_Auth::getInstance()->getIdentity()->user_id;
		$data = array(
			'author_id' => $userId,
			'subject' => $formDatas['subject'],
			'message' => $formDatas['message'],
			'created' => $this->_dateNow(),
			'modified' => $this->_dateNow(),
			'status' => 'not-deleted',
		);
		$this->insert($data);
	}


	/**
	 * View Announcement
	 * @return array
	 */
	public function fetchAnnouncement($announcementId)
	{
		$row = $this->fetchRow($this->select()->where('announcement_id = ?', $announcementId));
		return $row;
	}


	/**
	 * edit Announcement
	 * @param array formDatas
	 * @return mixed
	 */
	public function updateAnnouncement($formDatas = array())
	{
		$userId = Zend_Auth::getInstance()->getIdentity()->user_id;
		$data = array(
			'author_id' => $userId,
			'subject' => $formDatas['subject'],
			'message' => $formDatas['message'],
			'modified' => $this->_dateNow(),
		);

		$where = $this->getAdapter()->quoteInto('announcement_id = ?', $formDatas['id']);
		return $this->update($data, $where);
	}


	/**
	 * Delete Announcement
	 * @param int announcementId
	 * @return mixed
	 */
	public function deleteAnnouncement($announcementId)
	{
		$userId = Zend_Auth::getInstance()->getIdentity()->user_id;
		if(empty($userId))
		{
			$this->_redirect('/');
		}
		$data = array(
			'status' => 'deleted',
			'modified' => $this->_dateNow(),
		);

		$where = $this->getAdapter()->quoteInto('announcement_id = ?', $announcementId);
		return $this->update($data, $where);
	}


	/**
	 * Restore Announcement
	 * @param int announcementId
	 * @return mixed
	 */
	public function restoreAnnouncement($announcementId)
	{
		$userId = Zend_Auth::getInstance()->getIdentity()->user_id;
		if(empty($userId))
		{
			$this->_redirect('/');
		}
		$data = array(
			'status' => 'not-deleted',
			'modified' => $this->_dateNow(),
		);

		$where = $this->getAdapter()->quoteInto('announcement_id = ?', $announcementId);
		return $this->update($data, $where);
	}


	/**
	 * Fetch Not Deleted Announcement
	 * @return array results
	 */
	public function fetchNotDeleted()
	{
		$userId = Zend_Auth::getInstance()->getIdentity()->user_id;
		if(empty($userId))
		{
			$this->_redirect('/');
		}

		$results = $this->fetchAll($this->select()->where("status != ?", 'deleted')->order('created DESC'));
		return $results;
	}
}
?>