<?php
/**
 * Companies model 
 * @author Zaine
 */
class Application_Model_Tables_Companies extends Zend_Db_Table_Abstract
{
	
	/**
     * Set database table name 
     */
	protected $_name = 'companies';


	/**
     * Set database table prefix
     */
	public function __construct()
	{
		$this->_name = Zend_Registry::get('tablePrefix') . $this->_name;
		parent::__construct();
	}

    
    public function getCompanyInfo($id){
            
        $db = Zend_Db_Table::getDefaultAdapter();
        $sql = $db->select()->from(array('c' => $this->_name))
                            ->where('c.user_id = ?', $id);

        return $db->fetchRow($sql);
    }

	/**
     * Getting Extension Name and update it base on Id
     * @param int $id
     * @param string $photo
     * @return string Photo Name with extension
     */
	public function photoName($id, $photo)
	{
          
		$extension = end(explode(".", $photo));
		$photo = $id . "." . $extension;
		$datas = array(
			'company_pic' => $photo
		);
		$where = $this->getAdapter()->quoteInto('user_id = ' . $id, 1);
		$this->update($datas, $where);
		return $photo;
	}
    
    public function verificationAccount($id, $photo, $status)
	{
          
		if($status == 'bp'){
            $extension = end(explode(".", $photo));
            $photo = 'bp_'.$id . "." . $extension;
            $datas = array(
                'business_permit' => $photo,
            );
            $where = $this->getAdapter()->quoteInto('user_id = ' . $id, 1);
            $this->update($datas, $where);
            return $photo;
        }
        
        if($status == 'loa'){
            $extension = end(explode(".", $photo));
            $photo = 'loa_'.$id . "." . $extension;
            $datas = array(
                'letter_of_authorization' => $photo,
            );
            $where = $this->getAdapter()->quoteInto('user_id = ' . $id, 1);
            $this->update($datas, $where);
            return $photo;
        }
        
        
	}


	/**
	 * Add Company
	 * @param array $photo
	 * @param string $photo
	 * @return string | int If not empty, return Photo Name, else return Id
	 */
	public function addCompany($formDatas = array(), $photo)
	{
		$date = date('Y-m-d H:i:s');
		$id = $formDatas['user_id'];
		$datas = array(
			'user_id' => $id,
			'company_name' => $formDatas['company_name'],
			'company_address' => $formDatas['company_address'],
			'zipcode' => $formDatas['zipcode'],
			'company_phone' => $formDatas['company_phone'],
			'company_fax' => $formDatas['company_fax'],
			'company_email' => $formDatas['company_email'],
			'first_name' => $formDatas['first_name'],
			'middle_name' => $formDatas['middle_name'],
			'last_name' => $formDatas['last_name'],
			'designation' => $formDatas['designation'],
			'type_of_company' => $formDatas['type_of_company'],
			'created' => $date,
			'modified' => $date,
			'status' => 'not-deleted',
		);
		
		$this->insert($datas);

		if($photo != null){
			return $this->photoName($id, $photo);
		}
		else
		{
			$photo = array(
				'company_pic' => 'default.jpg'
			);
			$where = $this->getAdapter()->quoteInto('user_id = ' . $id, 1);
			$this->update($photo, $where);

			return $id;
		}
	}


	/**
	*  Updating Company
	*  @param array $formDatas
	*  @param string $photo
	*  @return string Photo Name if not empty
	*/
	public function updateCompany($formDatas = array())
	{
        
		$userId = Zend_Auth::getInstance()->getIdentity()->user_id;
		$modified = date("Y-m-d H:i:s");
		$datas = array(
			'company_name' => $formDatas['company_name'],
			'company_address' => $formDatas['company_address'],
			'zipcode' => $formDatas['zipcode'],
			'company_phone' => $formDatas['company_phone'],
			'company_fax' => $formDatas['company_fax'],
			'first_name' => $formDatas['first_name'],
			'last_name' => $formDatas['last_name'],
			'middle_name' => $formDatas['middle_name'],
			'designation' => $formDatas['designation'],
			'type_of_company' => $formDatas['type_of_company'],
			'modified' => $modified,
		);

		$where = $this->getAdapter()->quoteInto('user_id = '.$userId, 1);
		$this->update($datas, $where);

//		if($photo != null)
//		{
//			return $this->photoName($userId, $photo);
//		}
	}


	/**
	 *  updating Username
	 *  @param array $formDatas
	 *  @return result Update
	 */
	public function updateUsername($formDatas = array())
	{			
		$id = $formDatas['id'];
		$now = date("Y-m-d H:I:s");
		$datas = array(
			'company_email' => $formDatas['new_username'],
			'modified' => $now,
		);

		return $this->update($datas, 'user_id = ' . $id);
	}
	

	/**
	 * Fetch Company that the user/account is not yet active
	 */
	public function fetchActiveCompanies()
	{
		$select = $this->select()->setIntegrityCheck(false);
        $select->from('staff_companies')
               ->joinLeft('staff_users', "staff_companies.user_id = staff_users.user_id")
               ->where('staff_users.privilege = ?', 'employer')
               ->where('staff_users.status = ?', 'active')
               ->where('staff_companies.status = ?', 'not-deleted')
               ->order('staff_companies.created DESC');

        $results = $this->fetchAll($select);
		return $results;
	}


	/**
	 * Fetch Company (limit 9)
	 */
	public function fetchIndexCompanies()
	{
		$select = $this->select()->setIntegrityCheck(false);
        $select->from('staff_companies')
               ->joinLeft('staff_users', "staff_companies.user_id = staff_users.user_id")
               ->where('staff_users.privilege = ?', 'employer')
               ->where('staff_users.status = ?', 'active')
               ->where('staff_companies.status = ?', 'not-deleted')
               ->where('staff_companies.company_pic != ?', 'default.jpg')
               ->order('staff_companies.created DESC')
               ->limit(9, 0);

        $results = $this->fetchAll($select);
		return $results;
	}
}

?>