<?php
/**
 * Users model 
 * @author Zaine
 */	
class Application_Model_Tables_Employers extends Zend_Db_Table_Abstract
{

	/*
	 *	Set Database Table Name
	 */
	protected $_name = 'employees';


	/*
	 *	Set table prefix
	 */
	public function __construct()
	{
		$this->_name = Zend_registry::get('tablePrefix') . $this->_name;
		parent::__construct();
	}


	/**
	 *  Return Photoname
	 *  @param int $id
	 *  @param string $photo
	 *  @return string Photo with extension name
	 */
	public function photoName($id, $photo)
	{
		$extension = end(explode(".", $photo));
		$photo = $id . "." .$extension;
		$datas = array(
			'photo' => $photo
		);
		$where = $this->getAdapter()->quoteInto('employee_id = ' . $id, 1);
		$this->update($datas, $where);
		return $photo;
	}


	/**
	 *  Inserting Employee details
	 *  @param array $formDatas
	 *  @param string $photo
	 *  @return string Photo with extension name
	 */
	public function addEmployee($formDatas = array(), $photo)
	{
		$date = date("Y-m-d", strtotime($formDatas['year'] . "-" . $formDatas['month'] . "-" . $formDatas['day']));
		$now = date("Y-m-d H:i:s");
		$userId = Zend_Auth::getInstance()->getIdentity()->user_id;
	
		$datas = array(
			'user_id' => $userId,
			'first_name' => $formDatas['fname'],
			'middle_name' => $formDatas['mname'],
			'last_name' => $formDatas['lname'],
			'designation' => $formDatas['designation'],
			'last_working_date' => $date,
			'last_salary' => $formDatas['last_salary'],
			'unpaid_loan' => $formDatas['unpaid_loan'],
			'unpaid_advance' => $formDatas['unpaid_advance'],
			'attendance' => $formDatas['attendance'],
			'employment_status' => $formDatas['employment_status'],
			'employment_action' => $formDatas['employment_action'],
			'remarks' => $formDatas['remarks'],
			'recommendation' => $formDatas['recommendation'],
			'created' => $now,
			'modified' => $now,
			'status' => 'not-deleted',
		);

		$this->insert($datas);
		
		$id = $this->_db->lastInsertId();
		
		if($photo != null)
		{
			return $this->photoName($id, $photo);
		}
		else
		{
			$photo = array(
				'photo' => 'default.jpg'
			);
			$where = $this->getAdapter()->quoteInto('employee_id = ' . $id, 1);
			$this->update($photo, $where);
			return $id;
		}		
	}


	/**
	 *  Update Employee details
	 *  @param array $formDatas
	 *  @param string $photo
	 *  @param string If not empty, Photo with extension name
	 */
	public function updateEmployee($formDatas = array(), $photo, $id)
	{
		$date = date("Y-m-d", mktime(0, 0, 0, date("m", strtotime($formDatas['month'])), $formDatas['day'], $formDatas['year']));
		$now = date("Y-m-d H:i:s");
		$datas = array(
			'first_name' => $formDatas['fname'],
			'middle_name' => $formDatas['mname'],
			'last_name' => $formDatas['lname'],
			'designation' => $formDatas['designation'],
			'last_working_date' => $date,
			'last_salary' => $formDatas['last_salary'],
			'unpaid_loan' => $formDatas['unpaid_loan'],
			'unpaid_advance' => $formDatas['unpaid_advance'],
			'attendance' => $formDatas['attendance'],
			'employment_status' => $formDatas['employment_status'],
			'employment_action' => $formDatas['employment_action'],
			'remarks' => $formDatas['remarks'],
			'recommendation' => $formDatas['recommendation'],
			'modified' => $now,
		);
		
		$where = $this->getAdapter()->quoteInto('employee_id = '.$id, 1);
		$this->update($datas, $where);
		
		if($photo != null)
		{
			return $this->photoName($id, $photo);
		}
	}

}
?>