<?php
/**
 * Users model 
 * @author Zaine
 */
class Application_Model_Tables_Messages extends Zend_Db_Table_Abstract
{

	/**
	 * Set database table name 
	 */
	protected $_name = 'messages';
	
	
	/**
	 * Set table prefix 
	 */ 
	public function __construct() 
	{
		// Construct the table prefix	
		$this->_name = Zend_Registry::get('tablePrefix') . $this->_name;
		parent::__construct();
	}


	/**
	 *  Send Message
	 *  @param array ($formDatas)
	 *  @return mixed
	 */
	public function sendMessage($formDatas = array())
	{
		$date = date("Y-m-d H:i:s");
		$senderId = Zend_Auth::getInstance()->getIdentity()->user_id;

		$inbox = array(
			'sender_id' => $senderId,
			'receiver_id' => $formDatas['receiver_id'],
			'subject' => $formDatas['subject'],
			'message' => new Zend_Db_Expr("'".htmlentities($formDatas['message'])."'"),
			'connected' => 0,
			'date_created' => $date,
			'date_modified' => $date,
			'read' => 0,
			'location' => 'inbox',
			'status' => 'inbox',
		);

		$this->insert($inbox);

		$sent = array(
			'sender_id' => $senderId,
			'receiver_id' => $formDatas['receiver_id'],
			'subject' => $formDatas['subject'],
			'message' => new Zend_Db_Expr("'".htmlentities($formDatas['message'])."'"),
			'connected' => 0,
			'date_created' => $date,
			'date_modified' => $date,
			'read' => 1,
			'location' => 'sent',
			'status' => 'sent',
		);

		$this->insert($sent);
	}


	/**
	 *  Read Message
	 *  @param int $messageId
	 *  @return int
	 */
	public function readMessage($messageId)
	{
		$date = date("Y-m-d H:i:s");

		$data = array(
			'read' => 1,
			'date_modified' => $date,
		);

		$where = $this->getAdapter()->quoteInto('message_id = ?', $messageId);

		$this->update($data, $where);
	}


	/**
	 *  Delete Message
	 *  @param int $messageId
	 *  @return in
	 */
	public function deleteMessage($messageId)
	{
		$date = date("Y-m-d H:i:s");

		$data = array(
			'status' => 'trash',
			'date_modified' => $date,
		);

		$where = $this->getAdapter()->quoteInto('message_id = ?', $messageId);

		$this->update($data, $where);
	}


	/**
	 *  Restore Deleted Message
	 *  @param int $messageId
	 *  @param string $location
	 *  @return int
	 */
	public function restoreMessage($messageId, $location)
	{
		$date = date("Y-m-d H:i:s");

		$data = array(
			'status' => $location,
			'date_modified' => $date,
		);

		$where = $this->getAdapter()->quoteInto('message_id = ?', $messageId);

		$this->update($data, $where);
	}


	/**
	 *  Permanently delete Message
	 */
	public function removeMessage($messageId)
	{
		$row = $this->fetchRow("message_id = $messageId && status = 'trash'");
		$row->delete();
	}

}
?>	