<?php

class Admin_AnnouncementController extends Zend_Controller_Action
{
	
	/**
	 * Before dispatching, check the security in general
 	 */
	public function preDispatch() 
	{
		$this->view->auth = Zend_Auth::getInstance();
		if (!$this->view->auth->hasIdentity()) { 
			$this->_helper->flashMessenger->addMessage('<p class="msg error">Error accessing the resquested page.</p>');
			$this->_redirect('/');
		}
        
        // Check Privilege
        // Controllers and views are accessibleonly by admin
        if (Zend_Auth::getInstance()->getStorage()->read()->privilege != 'admin') {
            $this->_helper->flashMessenger->addMessage('<p class="msg error">Error accessing the resquested page.</p>');
            $this->_redirect('/');
        }
	}
	
    
	/**
	 * Initialize action controller here
	 */
    public function init()
    {
    	// Set the flash messenger	
		$this->view->flashMessenger = $this->_helper->flashMessenger->getMessages();
	}


	/**
	 * New Announcement here
	 */
	public function addAnnouncementAction()
	{
		$userId = Zend_Auth::getInstance()->getIdentity()->user_id;
		if(empty($userId))
		{
			$this->_redirect('/');
		}

		if($this->getRequest()->isPost())
		{
			$subject = $this->_request->getPost('subject');
			$message = $this->_request->getPost('message');
			if(empty($subject) || empty($message))
			{
				$notify = $this->_helper
                ->interface
                ->notify('Empty field', 'One of the field is empty.', 'notify-error');
    			$this->_helper->flashMessenger->addMessage($notify);
    			$this->_redirect('admin/announcement/add-announcement');
			}
			else
			{
				$formDatas = $this->getRequest()->getPost();
				$announcement = new Admin_Model_Tables_Announcements();
				$announcement->insertAnnouncement($formDatas);
				$notify = $this->_helper
                ->interface
                ->notify('Post Announcement', 'Succesfully posted Announcement.', 'notify-success');
    			$this->_helper->flashMessenger->addMessage($notify);
    			$this->_redirect('admin/announcement/manage-announcement');
			}
		}

	}


	/**
	 * Manage Announcement
	 */
	public function manageAnnouncementAction()
	{
		$userId = Zend_Auth::getInstance()->getIdentity()->user_id;
		if(empty($userId))
		{
			$this->_redirect('/');
		}

		$announcement = new Admin_Model_Tables_Announcements();
		$results = $announcement->listAnnouncement();
		$this->view->rows = $results;
	}


	/**
	 * Fetch announcement Row
	 */
	public function viewAction()
	{
		$userId = Zend_Auth::getInstance()->getIdentity()->user_id;
		$announcementId = $this->_request->getParam('id');
		if(empty($userId))
		{
			$this->_redirect('/');
		}
		if(empty($announcementId))
		{
			$this->_redirect('admin/announcement/manage-announcement');
		}

		$announcement = new Admin_Model_Tables_Announcements();
		$row = $announcement->fetchAnnouncement($announcementId);
		if($row)
		{
			$this->view->row = $row;
		}
	}


	/**
	 * Edit Announcement
	 */
	public function editAction()
	{
		$userId = Zend_Auth::getInstance()->getIdentity()->user_id;
		$announcementId = $this->_request->getParam('id');

		if(empty($userId))
		{
			$this->_redirect('/');
		}

		if(empty($announcementId))
		{
			$this->_redirect('admin/announcement/manage-announcement');
		}

		$announcement = new Admin_Model_Tables_Announcements();
		$row = $announcement->fetchAnnouncement($announcementId);

		if($row)
		{
			$this->view->row = $row;
		}

		if($this->getRequest()->isPost())
		{
			$subject = $this->_request->getPost('subject');
			$message = $this->_request->getPost('message');
			$announcementId = $this->_request->getPost('id');
			if(empty($subject) || empty($message) || empty($announcementId))
			{
				$notify = $this->_helper
                ->interface
                ->notify('Empty field', 'One of the field is empty.', 'notify-error');
    			$this->_helper->flashMessenger->addMessage($notify);
    			$this->_redirect("admin/announcement/edit/id/$announcementId");
			}
			else
			{
				$formDatas = $this->getRequest()->getPost();
				$update = $announcement->updateAnnouncement($formDatas);
				if($update)
				{
					$notify = $this->_helper
	                ->interface
	                ->notify('Post Announcement', 'Succesfully posted Announcement.', 'notify-success');
	    			$this->_helper->flashMessenger->addMessage($notify);
	    			$this->_redirect("admin/announcement/edit/id/$announcementId");
    			}
			}
		}
	}


	/**
	 * Delete Announcement
	 */
	public function deleteAction()
	{
		$userId = Zend_Auth::getInstance()->getIdentity()->user_id;
		$announcementId = $this->_request->getParam('id');

		if(empty($userId))
		{
			$this->_redirect('/');
		}

		if(empty($announcementId))
		{
			$this->_redirect('admin/announcement/manage-announcement');
		}

		$announcement = new Admin_Model_Tables_Announcements();
		$delete = $announcement->deleteAnnouncement($announcementId);

		if($delete)
		{
			$notify = $this->_helper
            ->interface
            ->notify('Deleted', 'Announcement Succesfully Deleted.', 'notify-success');
			$this->_helper->flashMessenger->addMessage($notify);
			$this->_redirect("admin/announcement/manage-announcement");
		}
	}


	/**
	 * Restore Announcement
	 */
	public function restoreAction()
	{
		$userId = Zend_Auth::getInstance()->getIdentity()->user_id;
		$announcementId = $this->_request->getParam('id');

		if(empty($userId))
		{
			$this->_redirect('/');
		}

		if(empty($announcementId))
		{
			$this->_redirect('admin/announcement/manage-announcement');
		}

		$announcement = new Admin_Model_Tables_Announcements();
		$restore = $announcement->restoreAnnouncement($announcementId);

		if($restore)
		{
			$notify = $this->_helper
            ->interface
            ->notify('Restored', 'Announcement Succesfully Restored.', 'notify-success');
			$this->_helper->flashMessenger->addMessage($notify);
			$this->_redirect("admin/announcement/manage-announcement");
		}
	}

}
?>