<?php

class Admin_CategoriesController extends Zend_Controller_Action
{
   
	/**
	 * Before dispatching, check the security in general
 	 */
	public function preDispatch() 
	{
		
		if (!Zend_Auth::getInstance()->hasIdentity()) {
			     
			$this->_helper
			->flashMessenger
			->addMessage('<p class="msg error">Error accessing the resquested page.</p>');
			
			$this->_redirect('/');
		}
        
        // Check Privilege
        if (Zend_Auth::getInstance()->getStorage()->read()->privilege != 'admin') {
            $this->_helper
            ->flashMessenger
            ->addMessage('<p class="msg error">Error accessing the resquested page.</p>');
        }
	}
	
    
	/**
	 * Initialize action controller here
	 */
    public function init()
    {
    	// Set the flash messenger	
		$this->view->flashMessenger = $this->_helper->flashMessenger->getMessages();
	}

    
    /**
     * Index page, redirect to view-videos
     */
   	public function indexAction() 
    {
   	    $this->_redirect('categories/add-category');
   	}


	/**
	 * Show the member's info
	 * Admin and member privilege
	 */
	public function viewCategoryAction()
    {    
        // Title of the page
        $this->view->headTitle('View All Categories');
        
        // Call videos' model
        $categories = new Application_Model_Tables_Categories();
        
        $results = $categories->fetchAll();
        
		// Zend paginator process
		$page 		= $this->_getParam('p', 1);
    	$paginator 	= Zend_Paginator::factory($results);
    	$paginator->setItemCountPerPage(30);
    	$paginator->setCurrentPageNumber($page);
    	$this->view->categories = $paginator;
        
    }
    
    
    /**
     * Add video
     * Admin privileges only
     */
    public function addCategoryAction()
    {
        // Page title
        $this->view->headTitle('Create New Category');
               
        if ($this->getRequest()->isPost()) {
        
            $categories  = new Application_Model_Tables_Categories();
            
            // Post data
            $formDatas = $this->getRequest()->getPost();
            
            // Create permalink
            $formDatas['alias'] = $this->_helper->generates->permalink($formDatas['name']);
                       
            // Now insert to database
            if ($categories->insertCategories($formDatas)) {
           	    $this->_helper->flashMessenger->addMessage('<p class="msg done">Category successfully added.</p>');
				$this->_redirect('categories/view-category');
            }
        }
        
        // Get the categories
        $categories = new Application_Model_Tables_Categories();
        
        // Display parent category
        $this->view->parentCategories = $categories->fetchAll();
    }
    
    
    /**
     * Edit video.
     */
    public function editCategoryAction()
    {
        // Page title
    	$this->view->headTitle('Edit Category');
    	
        $categoryId  = $this->_getParam('id');
        $categories  = new Application_Model_Tables_Categories();
        
        // If post
        if ($this->getRequest()->isPost()) {
            
        	// Post data
        	$formDatas = $this->getRequest()->getPost();
        	
        	// Store videoID to post data array
            $formDatas['category_id'] = $categoryId;
               
	        // Create permalink
            $formDatas['alias'] = $this->_helper->generates->permalink($formDatas['name']);

	        // Now update the table
            if ($categories->updateCategories($formDatas)) {
                $this->_helper->flashMessenger->addMessage('<p class="msg done">Category successfully updated.</p>');
                $this->_redirect('categories/view-category');
            } else {
            	$this->_helper->flashMessenger->addMessage('<p class="msg done">Try Again.</p>');
                $this->_redirect('categories/edit-category/id/' . $categoryId);
            }
        }

        // Display the video infos
        $this->view->formDatas = $categories->fetchRow('category_id =' .(int)$categoryId);
        
        // Display parent category
        $this->view->parentCategories = $categories->fetchAll('category_id != ' . (int)$categoryId);
    }
    
    
    /**
     * Deletion process.
     */
    public function deleteCategoryAction()
    {
        $this->view->headTitle('Delete Category');
        
        $this->_helper->flashMessenger['0'] = "Continue to confirm";
        
        if ($this->getRequest()->isPost()) {
            
            //$formDatas['categoryId'] = ''
            $categories = new Application_Model_Tables_Categories();
            
            try {
                
            } catch(exception $e) {
                throw $e;
            }
               
        }
    }
    
}