<?php

class Admin_EmployerController extends Zend_Controller_Action
{
	
    
    /**
     * Before dispatching, check the security in general
     */
    public function preDispatch() 
    {
        $this->view->auth = Zend_Auth::getInstance();
        if (!$this->view->auth->hasIdentity()) { 
            $this->_helper->flashMessenger->addMessage('<p class="msg error">Error accessing the resquested page.</p>');
            $this->_redirect('/');
        }
        
    }
    
    
	/**
	 * Initialize action controller here.
	 */
    public function init()
    {
        // Set the flash messenger
		$this->view->flashMessenger = $this->_helper->flashMessenger->getMessages();

        //session variable: urlSession
        $this->session = new Zend_Session_Namespace("urlSession");

    }

    
    /**
     * Index
     * @todo Temporarily redirect to registration. 
     */
    public function indexAction()
    {
        $this->view->headTitle('Employee Page');

        $this->view->bodyId = 'employee-page';

        //store current url to be pass on redirection if deleted
        $this->session->url = (!empty($_SERVER['HTTPS'])) ? "https://".$_SERVER['SERVER_NAME'].$_SERVER['REQUEST_URI'] : "http://".$_SERVER['SERVER_NAME'].$_SERVER['REQUEST_URI'];

        $employees = Zend_Db_Table_Abstract::getDefaultAdapter();
        $select = new Zend_Db_Select($employees);
        $select->from('staff_employees')
               ->joinInner('staff_companies', 'staff_employees.user_id = staff_companies.user_id', array('company_name'))
               ->order(array('staff_companies.company_name DESC', 'staff_employees.last_name'));
        $result = $employees->fetchAll($select);

        $this->view->employees_count = count($result);
        // Zend paginator processs
        $page       = $this->_getParam('p', 1);
        $paginator  = Zend_Paginator::factory($result);
        $paginator->setItemCountPerPage(20);
        $paginator->setCurrentPageNumber($page);
        //sending data to view
        $this->view->employees_data = $paginator;
    }


    /**
     * Delete Employee Action (Admin)
     */
    public function adminDeleteEmployeeAction()
    {
        $this->request = $this->getRequest();
        $id = $this->request->getParam('id');

        if(!empty($id))
        {
            $employee = new Application_Model_Tables_Employers();
            $date = date("Y-m-d H:i:s");
            $data = array(
                'modified' => $date,
                'status' => 'deleted'
                );
            $where = $employee->getAdapter()->quoteInto("employee_id = ?", $id);
            $employee->update($data, $where);

            //contains the url of the previous page
            $url = $this->session->url;
            //redirect to the page where it comes
            $this->_redirect($url);
        }
    }
    
    
    /**
     * List of Deleted Employees Action
     */
    public function adminDeletedEmployeeAction()
    {
        $this->view->headTitle('Deleted Employee Page');

        $this->view->bodyId = 'deleted-employee-page';

        //getrequest
        if($this->request = $this->getRequest())
        {
            //get parameter 'id'
            $id = $this->request->getParam('id');

            //instantiating employers table and updating of status
            if(!empty($id)){
                $employee = new Application_Model_Tables_Employers();
                $date = date("Y-m-d H:i:s");
                $data = array(
                    'modified' => $date,
                    'status' => 'not-deleted'
                    );
                $where = $employee->getAdapter()->quoteInto("employee_id = ?", $id);
                $employee->update($data, $where);
                $this->_helper->flashMessenger->addMessage("<div class='notify notify-success'>Data Succesfully restored.</div>");
                $this->_redirect('admin/employer/admin-deleted-employee');
            }
        }

        $adapter = Zend_Db_Table_Abstract::getDefaultAdapter();
        $select = new Zend_Db_Select($adapter);
        $select->from('staff_employees')
               ->joinInner('staff_companies', 'staff_employees.user_id = staff_companies.user_id', array('company_name'))
               ->where("staff_employees.status = 'deleted'")
               ->order(array('staff_companies.company_name DESC', 'staff_employees.last_name'));
        $result = $adapter->fetchAll($select);

        $this->view->employees_count = count($result);
        // Zend paginator processs
        $page       = $this->_getParam('p', 1);
        $paginator  = Zend_Paginator::factory($result);
        $paginator->setItemCountPerPage(20);
        $paginator->setCurrentPageNumber($page);
        //sending data to view
        $this->view->employees_deleted = $paginator;
    }



    /**
     * List of UnDeleted Employees Action
     */
    public function adminUndeletedEmployeeAction()
    {
        $this->view->headTitle('Undeleted Employee Page');

        $this->view->bodyId = 'undeleted-employee-page';

        //store current url to be pass on redirection if deleted
        $this->session->url = (!empty($_SERVER['HTTPS'])) ? "https://".$_SERVER['SERVER_NAME'].$_SERVER['REQUEST_URI'] : "http://".$_SERVER['SERVER_NAME'].$_SERVER['REQUEST_URI'];

        $employees = Zend_Db_Table_Abstract::getDefaultAdapter();
        $select = new Zend_Db_Select($employees);
        $select->from('staff_employees')
               ->joinInner("staff_companies", "staff_employees.user_id = staff_companies.user_id", array('company_name'))
               ->where("staff_employees.status != 'deleted'")
               ->order(array('staff_companies.company_name DESC', 'staff_employees.last_name'));
        $result = $employees->fetchAll($select);

        $this->view->employees_undeleted = $result;
    }



    
    /**
     * Add employee action
     */
    public function addEmployeeAction()
    {
        // Page title.
        $this->view->headTitle('Add Employee');
        
        // Custom id of body.
        // @todo it will be removed in the future.
        $this->view->bodyId = 'add-employee-page';   
    }
    

    /**
     * edit employee action
     */
    public function adminEditEmployeeAction()
    {
        // Page title.
        $this->view->headTitle('Edit Employee');
        
        // Custom id of body.
        // @todo it will be removed in the future.
        $this->view->bodyId = 'admin-edit-employee-page'; 

        $this->request = $this->getRequest();
        $id = $this->request->getParam('id');

        //edit
        if(!empty($id))
        {
            $employee = new Application_Model_Tables_Employers();
            $this->view->row = $employee->fetchRow($employee->select()->where("employee_id = ?", $id));
            $result = $employee->fetchRow($employee->select()->where("employee_id = ?", $id));
        }

        //if click submit
        if($this->getRequest()->isPost())
        {
            //upload still not done ( undecided )
            $id = $this->_request->getPost('id');
            $first_name = $this->_request->getPost('first_name');
            $middle_name = $this->_request->getPost('middle_name');
            $last_name = $this->_request->getPost('last_name');
            $designation = $this->_request->getPost('designation');
            $last_salary = $this->_request->getPost('last_salary');
            $unpaid_loan = $this->_request->getPost('unpaid_loan');
            $unpaid_advance = $this->_request->getPost('unpaid_advance');
            $attendance = $this->_request->getPost('attendance');
            $employment_status = $this->_request->getPost('employment_status');
            $employment_action = $this->_request->getPost('employment_action');
            $status = $this->_request->getPost('status');
            $remarks = $this->_request->getPost('remarks');
            $recommendation = $this->_request->getPost('recommendation');
            
            if(
                empty($id) || empty($first_name) || empty($middle_name) || empty($last_name) || empty($designation) ||  empty($attendance) || empty($employment_status) || empty($employment_action) || empty($status) || empty($remarks) || empty($recommendation)
            )
            {
                $this->view->flashMessenger[] = "<div class='msg error'>One of the fields are empty.</div>";
                $this->_redirect('admin/employer/');          
            }
            else
            {
                $formDatas = $this->getRequest()->getPost();
                $employee = new Admin_Model_Tables_Employers();
                $id = $this->_request->getPost('id');

                $employee->adminUpdateEmployee($formDatas);
                $this->_redirect('admin/employer');
                /*
                $adapter = new Zend_File_Transfer_Adapter_Http();
                $adapter->addValidator('IsImage', false)
                        ->addValidator('Size', false, 40000);
                $uploadedfile = $adapter->getFileName();  
                $uploadPath = "/home/puvprime/public_html/rad05/public/uploads/profile_pic";
                
                if(empty($uploadedFile))                      
                {

                }
                else
                {

                }
                */
            }
        }
    }


    /**
     * View employee action
     */
    public function adminViewEmployeeAction()
    {
        // Page title.
        $this->view->headTitle('View Employee');
        
        // Custom id of body.
        // @todo it will be removed in the future.
        $this->view->bodyId = 'admin-view-employee-page'; 

        $this->request = $this->getRequest();
        $id = $this->request->getParam('id');

        //edit
        if(!empty($id))
        {
            $adapter = Zend_Db_Table_Abstract::getDefaultAdapter();
            $select = new Zend_Db_Select($adapter);
            $select->from('staff_employees')
               ->joinInner('staff_companies', 'staff_employees.user_id = staff_companies.user_id', array('company_name'))
               ->order(array('staff_companies.company_name DESC', 'staff_employees.last_name'))
               ->where("employee_id = ?", $id);
            $result = $adapter->fetchRow($select);
            $this->view->row = $result;
            /*
            $employee = new Application_Model_Tables_Employers();
            $this->view->row = $employee->fetchRow($employee->select()->where("employee_id = ?", $id));
            $result = $employee->fetchRow($employee->select()->where("employee_id = ?", $id));
            */
        }
    }

       
}