<?php

class Admin_IndexController extends Zend_Controller_Action
{
	
	/**
	 * Initialize action controller here.
	 */
    public function init()
    {
        // Set the flash messenger
		$this->view->flashMessenger = $this->_helper->flashMessenger->getMessages();
        
    }


    /**
     * Index page.
     */
    public function indexAction()
    {
        if(Zend_Auth::getInstance()->getIdentity()->user_id == 1)
        {
            $this->_redirect('admin/index/dashboard');
        }

        $this->view->login = true;
        
        // Page title
        $this->view->headTitle('Login');
        
    }
    
    
    /**
     * Dashboard page
     * 
     * @access 
     */
    public function dashboardAction()
    {
        // Page title
        $this->view->headTitle('Dashboard');
        
        // Check identity.
        if (Zend_Auth::getInstance()->getStorage()->read()->privilege != 'admin') {
            
            $notify = $this->_helper
            ->interface
            ->notify('Secure Page', 'Error accessing the resquested page.', 'notify-error');
            $this->_helper->flashMessenger->addMessage($notify);
            $this->_redirect('admin');
        }
        
        // Instantiate Users
        $users = new Admin_Model_Tables_Users();    
        // Count active users
        $users_active = $users->fetchAll($users->select()->where("status = 'active'"));
        $this->view->users_active_count = $users_active->count();
        // Count inactive users
        $users_inactive = $users->fetchAll($users->select()->where("status = 'inactive'"));
        $this->view->users_inactive_count = $users_inactive->count();

        // Instantiate Employees
        $employees = new Admin_Model_Tables_Employers();
        // Count Undeleted employees
        $employees_undeleted = $employees->fetchAll($employees->select()->where("status != 'deleted'"));
        $this->view->employees_undeleted_count = $employees_undeleted->count();
        // Count deleted employees
        $employees_deleted = $employees->fetchAll($employees->select()->where("status = 'deleted'"));
        $this->view->employees_deleted_count = $employees_deleted->count();

        // Instantiate Companies
        $companies = new Admin_Model_Tables_Companies();
        $companies_rows = $companies->fetchAll($companies->select());
        $this->view->companies_data = $companies_rows;

        
    }
    
    
	/**
	 * Handles login validation.
	 */
    public function loginAction()
    {
        
        // Page title.
        $this->view->headTitle('Log In');
        
        if ($this->getRequest()->isPost()) {
          
    		// Collect the data from the user.
    		$f = new Zend_Filter_StripTags();
            
            $username = $f->filter($this->_request->getPost('username'));
    		$password = $f->filter($this->_request->getPost('password'));
    		
    		if (empty($username)) {
    		    
                $notify = $this->_helper
                ->interface
                ->notify('Forgot Password', 'The password you have entered is incorrect', 'notify-error');
    			$this->_helper->flashMessenger->addMessage($notify);

    		} else {
    			
                // Get the default adapter.
    			$dbAdapter		= Zend_Db_Table::getDefaultAdapter();
    			// Get the prefix
    			$dbTableName 	= Zend_Registry::get('tablePrefix') . 'users';
    			
    			// Use advance authentication, with status = active
    			$authAdapter	= new Zend_Auth_Adapter_DbTable($dbAdapter);
    			
    			$authAdapter->setTableName($dbTableName);
    			$authAdapter->setIdentityColumn('username');
    		 	$authAdapter->setCredentialColumn('password');
    		 	// $authAdapter->set
    		 	
    			// Set the input credential values to authenticate against.
    			$authAdapter->setIdentity($username);
    			$authAdapter->setCredential(md5($password));
    			
    			// Do the authentication.
    			$auth 	= Zend_Auth::getInstance();
    			$result = $auth->authenticate($authAdapter);
    			
    			if ($result->isValid()) {
    				
    				// Success: store database row to auth's storage.
    				// System. (Not the password though!).
    				$data = $authAdapter->getResultRowObject(null, 'password');
    				$auth->getStorage()->write($data);

                    $authStorage = new Zend_Session_Namespace('authstorage');
                    $authStorage->admin = $auth->getStorage()->read();
    				
                    $notify = $this->_helper
                    ->interface
                    ->notify('Welcome', 'Successfully login.', 'notify-success');
                    $this->_helper->flashMessenger->addMessage($notify);
                    
                    $this->_redirect('admin/index/dashboard'); 
                     
    			} else {
    				
                    // Failure: clear database row from session.
                    $notify = $this->_helper
                    ->interface
                    ->notify('Forgot Password', 'The password you have entered is incorrect', 'notify-error');
                    $this->_helper->flashMessenger->addMessage($notify);
                }
                
            }
        }

        $this->_redirect('admin');    
	}
	 
 	
	/**
	 * Logout action
	 */
	public function logoutAction() 
	{
        $authSession = new Zend_Session_Namespace('authstorage');
        unset($authSession->admin);

        Zend_Auth::getInstance()->clearIdentity();

        $notify = $this->_helper
        ->interface
        ->notify('Bye', 'Successfully logout.', 'notify-success');
        $this->_helper->flashMessenger->addMessage($notify);
        
        
		$this->_redirect('admin');
	}

}