<?php

	class Admin_Model_Tables_Companies extends Zend_Db_Table_Abstract
	{
		
		/*
			Set Database Table name
		*/
		protected $_name = 'companies';

		/*
			Set Table Prefix
		*/
		public function __construct()
		{
			$this->_name = Zend_Registry::get('tablePrefix') . $this->_name;
			parent::__construct();
		}
        
        public function getCompanyInfo($id){
            
            $db = Zend_Db_Table::getDefaultAdapter();
            $sql = $db->select()->from(array('c' => $this->_name))
                                ->where('c.user_id = ?', $id);
            
            return $db->fetchRow($sql);
        }
        
        
		//function for adding a new company
		public function addCompany($formDatas = array())
		{
			//current date
			$date = date('Y-m-d H:i:s');
			$datas = array(
				'company_name' => $formDatas['company_name'],
				'company_address' => $formDatas['company_address'],
				'first_name' => $formDatas['first_name'],
				'middle_name' => $formDatas['middle_name'],
				'last_name' => $formDatas['last_name'],
				'designation' => $formDatas['designation'],
				'field_name_1' => $formDatas['field_name_1'],
				'field_name_2' => $formDatas['field_name_2'],
				'created' => $date,
				'modified' => $date,
			);
			
			return $this->insert($datas);
		}

        public function verificationAccount($id, $photo, $status)
        {

            if($status == 'bp'){
                $extension = end(explode(".", $photo));
                $photo = 'bp_'.$id . "." . $extension;
                $datas = array(
                    'business_permit' => $photo,
                );
                $where = $this->getAdapter()->quoteInto('user_id = ' . $id, 1);
                $this->update($datas, $where);
                return $photo;
            }

            if($status == 'loa'){
                $extension = end(explode(".", $photo));
                $photo = 'loa_'.$id . "." . $extension;
                $datas = array(
                    'letter_of_authorization' => $photo,
                );
                $where = $this->getAdapter()->quoteInto('user_id = ' . $id, 1);
                $this->update($datas, $where);
                return $photo;
            }


        }

        /**
        *  Updating Company
        *  @param array $formDatas
        *  @param string $photo
        *  @return string Photo Name if not empty
        */
        public function updateCompany($id,$formDatas = array())
        {
            $userId = $id;
            $modified = date("Y-m-d H:i:s");
            $datas = array(
                'company_name' => $formDatas['company_name'],
                'company_address' => $formDatas['company_address'],
                'zipcode' => $formDatas['zipcode'],
                'company_phone' => $formDatas['company_phone'],
                'company_fax' => $formDatas['company_fax'],
                'first_name' => $formDatas['first_name'],
                'last_name' => $formDatas['last_name'],
                'middle_name' => $formDatas['middle_name'],
                'designation' => $formDatas['designation'],
                'type_of_company' => $formDatas['type_of_company'],
                'modified' => $modified,
            );

            $where = $this->getAdapter()->quoteInto('user_id = '.$userId, 1);
            $this->update($datas, $where);

    //		if($photo != null)
    //		{
    //			return $this->photoName($userId, $photo);
    //		}
        }
        
        /**
            * Getting Extension Name and update it base on Id
            * @param int $id
            * @param string $photo
            * @return string Photo Name with extension
            */
        public function photoName($id,$photo)
        {

            $extension = end(explode(".", $photo));
            $photo = $id . "." . $extension;
            $datas = array(
                'company_pic' => $photo
            );
            $where = $this->getAdapter()->quoteInto('user_id = ' . $id, 1);
            $this->update($datas, $where);
            return $photo;
        }

		public function adminUpdateCompany($formDatas = array())
		{
			$id = $formDatas['id'];
			$date = date("Y-m-d H:i:s");			

			$datas = array(
				'company_name' => $formDatas['company_name'],
				'company_address' => $formDatas['company_address'],
				'company_phone' => $formDatas['company_phone'],
				'company_fax' => $formDatas['company_fax'],
				'company_email' => $formDatas['company_email'],
				'first_name' => $formDatas['first_name'],
				'middle_name' => $formDatas['middle_name'],
				'last_name' => $formDatas['last_name'],
				'designation' => $formDatas['designation'],
				'type_of_company' => $formDatas['type_of_company'],
				'modified' => $date,
				'status' => $formDatas['status'],
			);
			
			$where = $this->getAdapter()->quoteInto("company_id = ?", $id);
			$this->update($datas, $where);
		}

		public function adminDeleteCompany($id)
		{
			$date = date("Y-m-d H:i:s");
			$datas = array(
				'modified' => $date,
				'status' => 'deleted',
			);

			$where = $this->getAdapter()->quoteInto("company_id = ?", $id);
			$this->update($datas, $where);
		}


		public function adminUndeleteCompany($id)
		{
			$date = date("Y-m-d H:i:s");
			$datas = array(
				'modified' => $date,
				'status' => 'not-deleted',				
			);

			$where = $this->getAdapter()->quoteInto("company_id = ?", $id);
			$this->update($datas, $where);
		}
        
        public function updateAccountVerification($id, $status, $account){
            
            if($account == 'LOA'){
                if($status == 'Unverified' || $status == Null){
                    $datas = array(
                        'letter_of_authorization_status' => 'Verified'
                    );
                }else{
                    $datas = array(
                        'letter_of_authorization_status' => 'Unverified'
                    );
                }
            }
            
            if($account == 'BP'){
                if($status == 'Unverified' || $status == Null){
                    $datas = array(
                        'business_permit_status' => 'Verified'
                    );
                }else{
                    $datas = array(
                        'business_permit_status' => 'Unverified'
                    );
                }
            }
            
            $where = $this->getAdapter()->quoteInto("user_id = ?", $id);
            return $this->update($datas, $where);
                    
        }
        
      
			
	}

?>