<?php
	
	class Admin_Model_Tables_Employers extends Zend_Db_Table_Abstract
	{

		/*
			Set Database Table Name
		*/
		protected $_name = 'employees';

		/*
			Set table prefix
		*/
		public function __construct()
		{
			$this->_name = Zend_registry::get('tablePrefix') . $this->_name;
			parent::__construct();
		}

		//function for getting extension name and update it base on id
		public function photoName($id, $photo)
		{

			$extension = explode(".", $photo);
			$extension = end($extension);
			$photo = $id . "." .$extension;
			$datas = array(
				'photo' => $photo
			);
			$where = $this->getAdapter()->quoteInto('employee_id = ' . $id, 1);
			$this->update($datas, $where);
			return $photo;
		}

		//declaring the parameter as array
		public function addEmployee($formDatas = array(), $photo)
		{
			//convert the date to format Y-m-d
			$date = date("Y-m-d", strtotime($formDatas['year'] . "-" . $formDatas['month'] . "-" . $formDatas['day']));
			$now = date("Y-m-d H:i:s");
			$admin_id = $_SESSION['user_id'];
			//inserting the array to another array variable($datas)
			$datas = array(
				'admin_id' => $admin_id,
				'full_name' => $formDatas['name'],
				'designation' => $formDatas['designation'],
				'last_working_date' => $date,
				'last_salary' => $formDatas['last_salary'],
				'attendance' => $formDatas['attendance'],
				'remarks' => $formDatas['remarks'],
				'recommendation' => $formDatas['recommendation'],
				'created' => $now,
				'modified' => $now,
			);

			//insert the data
			$this->insert($datas);
			
			//Fetch the last insert id
			$id = $this->_db->lastInsertId();
			
			//call function photoName for updating the photoname base on id
			if($photo != null){
				return $this->photoName($id, $photo);
			}else{
				//setting photo field to default.jpg
				$photo = array(
					'photo' => 'default.jpg'
				);
				$where = $this->getAdapter()->quoteInto('employee_id = ' . $id, 1);
				$this->update($photo, $where);
			}
			
		}

		//function for updating Employee
		public function updateEmployee($formDatas = array(), $photo)
		{
			//hidden id for updating
			$id = $formDatas['id'];
			//convert the date to format Y-m-d
			$date = date("Y-m-d", strtotime($formDatas['year'] . "-" . $formDatas['month'] . "-" . $formDatas['day']));
			//update last date modified
			$now = date("Y-m-d H:i:s");
			$datas = array(
				'full_name' => $formDatas['name'],
				'designation' => $formDatas['designation'],
				'last_working_date' => $date,
				'last_salary' => $formDatas['last_salary'],
				'attendance' => $formDatas['attendance'],
				'remarks' => $formDatas['remarks'],
				'recommendation' => $formDatas['recommendation'],
				'modified' => $now,
			);
			
			$where = $this->getAdapter()->quoteInto('employee_id = '.$id, 1);
			$this->update($datas, $where);
			
			if($photo != null)
			{
				return $this->photoName($id, $photo);
			}
		}

		public function adminUpdateEmployee($formDatas = array())
		{
			$id = $formDatas['id'];

			$now = date("Y-m-d H:i:s");
			$datas = array(
				'first_name' => $formDatas['first_name'],
				'middle_name' => $formDatas['middle_name'],
				'last_name' => $formDatas['last_name'],
				'designation' => $formDatas['designation'],
				'last_salary' => $formDatas['last_salary'],
				'unpaid_loan' => $formDatas['unpaid_loan'],
				'unpaid_advance' => $formDatas['unpaid_advance'],
				'attendance' => $formDatas['attendance'],
				'employment_status' => $formDatas['employment_status'],
				'employment_action' => $formDatas['employment_action'],
				'remarks' => $formDatas['remarks'],
				'recommendation' => $formDatas['recommendation'],
				'modified' => $now,
				'status' => $formDatas['status'],
				);

			if($formDatas['date'] != NULL)
			{	
				$datas['last_working_date'] = date("Y-m-d", strtotime($formDatas['date']));
			}

			$where = $this->getAdapter()->quoteInto('employee_id = '.$id, 1);
			$this->update($datas, $where);
		}


		public function adminAddEmployee($formDatas = array(), $photo)
		{
			//convert the date to format Y-m-d
			$date = date("Y-m-d", strtotime($formDatas['last_working_date']));
			$now = date("Y-m-d H:i:s");
			$admin_id = $formDatas['user_id'];
			//inserting the array to another array variable($datas)
			$datas = array(
				'user_id' => $admin_id,
				'first_name' => $formDatas['first_name'],
				'middle_name' => $formDatas['middle_name'],
				'last_name' => $formDatas['last_name'],				
				'designation' => $formDatas['designation'],
				'last_working_date' => $date,
				'last_salary' => $formDatas['last_salary'],
				'unpaid_loan' => $formDatas['unpaid_loan'],
				'unpaid_advance' => $formDatas['unpaid_advance'],				
				'attendance' => $formDatas['attendance'],
				'employment_status' => $formDatas['employment_status'],
				'employment_action' => $formDatas['employment_action'],
				'remarks' => $formDatas['remarks'],
				'recommendation' => $formDatas['recommendation'],
				'created' => $now,
				'modified' => $now,
				'status' => 'not-deleted',
			);

			//insert the data
			$this->insert($datas);
			
			//Fetch the last insert id
			$id = $this->_db->lastInsertId();
			
			//call function photoName for updating the photoname base on id
			if($photo != null){
				return $this->photoName($id, $photo);
			}else{
				//setting photo field to default.jpg
				$photo = array(
					'photo' => 'default.jpg'
				);
				$where = $this->getAdapter()->quoteInto('employee_id = ' . $id, 1);
				$this->update($photo, $where);
				return $id;
			}
		}

	}
?>