<?php

/**
 * Prime Controller Plugin LayoutLoader  
 */
class Amz_Controller_Plugin_ZendCache extends Zend_Controller_Plugin_Abstract {

    /**
     * Predispatch method that runs before the the dispatch loop
     * @param Zend_Controller_Request_Abstract $request 
     */
    public function preDispatch(Zend_Controller_Request_Abstract $request) {

        $this->_redirectUrl($request);
        $this->_zendCache($request);
    }

    /**
     * Auth Session Switcher
     * @param Zend_Controller_Request_Abstract $request 
     */
    protected function _zendCache(Zend_Controller_Request_Abstract $request) {
        $controllerName = $request->getControllerName();
        $action = $request->getActionName();

        $frontendOptions = array(
            'lifetime' => 14400,
//            'debug_header' => true,
            'content_type_memorization' => true,
            'default_options' => array(
                'cache' => false,
                'cache_with_get_variables' => true,
                'cache_with_post_variables' => true,
                'cache_with_session_variables' => true,
                'cache_with_cookie_variables' => true,
            ),
            'regexps' => array(
                // cache the whole IndexController
//                '^.*$' => array('cache' => false),
                '^/$' => array('cache' => true),
                '^/.*public' => array('cache' => false),
                '^/.*index/' => array('cache' => false),
                '^/index' => array('cache' => true),
                '^/index/search' => array('cache' => false),
                '^/index/login' => array('cache' => false),
                '^/index/logout' => array('cache' => false),
                '^/index/search-view' => array('cache' => false),
                '^/index/pending' => array('cache' => false),
                '^/index/confirm' => array('cache' => false),
                '^/.*pages' => array('cache' => false),
                '^/.*employer' => array('cache' => false),
                '^/.*employees' => array('cache' => false),
                '^/.*error' => array('cache' => false),
                '^/.*messages' => array('cache' => false),
                '^/.*settings' => array('cache' => false),
                '^/.*users' => array('cache' => false),
                '^/.*categories' => array('cache' => false),
                '^/.*connections' => array('cache' => false),
                '^/.*admin' => array('cache' => false),
            // place more controller links here to cache them
            )
        );

        $backendOptions = array(
            'cache_dir' => './tmp/',
            'file_name_prefix' => $controllerName,
        );

        // getting a Zend_Cache_Frontend_Page object
        $cache = Zend_Cache::factory('Page', 'File', $frontendOptions, $backendOptions);
        
        $cache->start($controllerName);
        Zend_Registry::set($action, $cache);
        $cache->clean(Zend_Cache::CLEANING_MODE_OLD);
        
    }

    protected function _redirectUrl(Zend_Controller_Request_Abstract $request) {
        $controller = $request->getControllerName();
        $action = $request->getActionName();
    }

}